<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class logger_admin extends MX_Controller
{

    public function index()
    {
        $this->load->model('logger/crud');

        return array('content' => $this->crud->render(), 'title' => $this->lang->line('Logger'));
    }

}
