CREATE TABLE IF NOT EXISTS `logger` ( 
`id_logger` int(11) NOT NULL AUTO_INCREMENT,
`key` varchar(255) CHARACTER SET utf8 NOT NULL,
`ip` varchar(255) CHARACTER SET utf8,
`date` DATETIME,
`value` text,
PRIMARY KEY (`id_logger`) 
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
